# Extended Guide on Survey Features
### On this page
  * [Configuring Survey Permissions for Non-Admin Roles](https://help.sap.com/docs/leanix/ea/extended-guide-on-survey-features#configuring-survey-permissions-for-non-admin-roles)
  * [Safety Net for Survey Notifications](https://help.sap.com/docs/leanix/ea/extended-guide-on-survey-features#safety-net-for-survey-notifications)
  * [Activating and Deactivating Safety Net](https://help.sap.com/docs/leanix/ea/extended-guide-on-survey-features#activating-and-deactivating-safety-net)
  * [Available Actions When Safety Net is Triggered](https://help.sap.com/docs/leanix/ea/extended-guide-on-survey-features#available-actions-when-safety-net-is-triggered)
  * [Assigning Fact Sheet Subscriptions Through Surveys](https://help.sap.com/docs/leanix/ea/extended-guide-on-survey-features#assigning-fact-sheet-subscriptions-through-surveys)
  * [Survey API](https://help.sap.com/docs/leanix/ea/extended-guide-on-survey-features#survey-api)


Grant non-admins survey creation rights, prevent unintended notifications with Safety Net activation, and learn how to use API for survey management
